@@ -19,6 +19,7 @@ from covsirphy.util.error import NotRegisteredMainError, NotRegisteredExtraError
 from covsirphy.util.filer import save_dataframe
 from covsirphy.util.argument import find_args
 from covsirphy.util.filer import Filer
+from covsirphy.util.evaluator import Evaluator
 from covsirphy.util.term import Term, Word
 # visualization
 from covsirphy.visualization.vbase import VisualizeBase
@@ -57,6 +58,8 @@ from covsirphy.simulation.simulator import ODESimulator
 from covsirphy.phase.phase_unit import PhaseUnit
 from covsirphy.phase.phase_series import PhaseSeries
 from covsirphy.phase.phase_estimator import MPEstimator
+# regression
+from covsirphy.regression.reg_handler import RegressionHandler
 # analysis
 from covsirphy.analysis.example_data import ExampleData
 from covsirphy.analysis.data_handler import DataHandler
@@ -89,7 +92,7 @@ def get_citation():
 
 __all__ = [
     # util
-    "StopWatch", "deprecate", "find_args", "Term", "Filer",
+    "StopWatch", "deprecate", "find_args", "Term", "Filer", "Evaluator",
     "SubsetNotFoundError", "ScenarioNotFoundError", "UnExecutedError",
     "PCRIncorrectPreconditionError", "NotInteractiveError",
     "UnExpectedValueError", "NotRegisteredMainError", "NotRegisteredExtraError",
@@ -107,6 +110,8 @@ __all__ = [
     "ODESimulator", "Estimator",
     # phase
     "PhaseSeries", "PhaseUnit", "MPEstimator",
+    # regression
+    "RegressionHandler",
     # analysis
     "ExampleData", "Scenario", "ModelValidator", "ParamTracker", "DataHandler",
     # worldwide
