@@ -465,7 +465,7 @@ class DataHandler(Term):
         except NotRegisteredExtraError:
             return self.records(main=True, extras=False, past=True, future=True)
 
-    def estimate_delay(self, indicator, target, delay_name="Period Length"):
+    def estimate_delay(self, indicator, target, min_size=7, use_difference=False, delay_name="Period Length"):
         """
         Estimate the average day [days] between the indicator and the target.
         We assume that the indicator impact on the target value with delay.
@@ -474,6 +474,8 @@ class DataHandler(Term):
         Args:
             indicator (str): indicator name, a column of any registered datasets
             target (str): target name, a column of any registered datasets
+            min_size (int): minimum size of the delay period
+            use_difference (bool): if True, use first discrete difference of target
             delay_name (str): column name of delay in the output dataframe
 
         Raises:
@@ -500,6 +502,8 @@ class DataHandler(Term):
         record_df = self.records_all()
         self._ensure_list(
             [indicator, target], candidates=record_df.columns.tolist(), name="indicator and target")
+        if use_difference:
+            record_df[target] = record_df[target].diff()
         pivot_df = record_df.pivot_table(values=indicator, index=target)
         run_df = pivot_df.copy()
         # Convert index (target) to serial numbers
@@ -509,7 +513,7 @@ class DataHandler(Term):
         series = run_df.reset_index(drop=True).iloc[:, 0].dropna()
         # Detection with Ruptures using indicator values
         warnings.simplefilter("ignore", category=RuntimeWarning)
-        algorithm = rpt.Pelt(model="rbf", jump=1, min_size=0)
+        algorithm = rpt.Pelt(model="rbf", jump=1, min_size=min_size)
         try:
             results = algorithm.fit_predict(series.values, pen=0.5)
         except ValueError:
