@@ -14,17 +14,19 @@ from covsirphy.analysis.example_data import ExampleData
 
 class ModelValidator(Term):
     """
-    Validate a ODE model as follows.
-    - Create a model parameter set, phase length and initial values randomly.
-    - Simulate the number of cases with an user-defined parameter set.
-    - Perform parameter estimation with the theoretical data (the dataset created with step 1).
-    - Compare the user-defined parameter set and estimated parameter set.
-    - Repeat with anather set of parameters.
-    - Small difference of the two parameter sets means that the model can be used for parameter estimation.
+    Evaluate ODE models performance as follows.
+    1. Select model parameter sets randomly
+    2. Set user-defined/random phase duration
+    3. Perform simulation with a specified ODE model
+    4. Perform parameter estimation
+    5. Compare the estimated parameters and the parameters produced with th 1st step
+    6. Repeat trials (1 trial = from the 1st step to the 5th step)
+    Small difference is expected in the 6th step.
 
     Args:
         tau (int): tau value [min]
         n_trials (int): the number of trials
+        step_n (int or None): the number of steps in simulation (over 2) or None (randomly selected)
         seed (int): random seed
 
     Note:
@@ -32,11 +34,17 @@ class ModelValidator(Term):
         Estimators know tau values before parameter estimation.
     """
 
-    def __init__(self, tau=1440, n_trials=8, seed=0):
-        self.n_trials = self._ensure_natural_int(n_trials, name="n_trials")
-        self.seed = self._ensure_natural_int(
-            seed, name="seed", include_zero=True)
-        self.tau = self._ensure_tau(tau)
+    def __init__(self, tau=1440, n_trials=8, step_n=None, seed=0):
+        self._tau = self._ensure_tau(tau)
+        self._n_trials = self._ensure_natural_int(n_trials, name="n_trials")
+        self._seed = self._ensure_natural_int(seed, name="seed", include_zero=True)
+        # list[int]: the number of steps for each trials
+        if step_n is None:
+            np.random.seed(seed)
+            self._step_n_list = np.random.randint(5, 60, n_trials)
+        else:
+            self._ensure_int_range(step_n, name="step_n", value_range=(3, None))
+            self._step_n_list = [step_n for _ in range(n_trials)]
         # Validated models
         self.model_names = []
         # Dataframes of results created by ._get_result()
@@ -60,7 +68,7 @@ class ModelValidator(Term):
             raise ValueError(f"{model.NAME} has been validated.")
         self.model_names.append(model.NAME)
         # Setup: create parameter set, phase length and processor
-        df = self._setup(model, n_trials=self.n_trials, seed=self.seed)
+        df = self._setup(model)
         processor = self._processor(model, df)
         # Parameter estimation
         units_estimated = processor.run(
@@ -69,14 +77,12 @@ class ModelValidator(Term):
         self._results.append(self._get_result(model, df, units_estimated))
         return self
 
-    def _setup(self, model, n_trials, seed):
+    def _setup(self, model):
         """
-        Create a model parameter set, phase length randomly.
+        Create a model parameter set randomly.
 
         Args:
             model (covsirphy.ModelBase): ODE model
-            n_trials (int): the number of trials
-            seed (int): random seed
 
         Returns:
             pandas.DataFrame:
@@ -86,20 +92,17 @@ class ModelValidator(Term):
                     - Rt (float): reproduction number
                     - step_n (int): step number of simulation
         """
-        np.random.seed(seed)
+        np.random.seed(self._seed)
         population = model.EXAMPLE[self.N.lower()]
         # Parameter set
         parameters = model.PARAMETERS[:]
-        df = pd.DataFrame(
-            np.random.rand(n_trials, len(parameters)), columns=parameters)
+        df = pd.DataFrame(np.random.rand(self._n_trials, len(parameters)), columns=parameters)
         # Reproduction number
-        df[self.RT] = df.apply(
-            lambda x: model(population, **x.to_dict()).calc_r0(),
-            axis=1)
+        df[self.RT] = df.apply(lambda x: model(population, **x.to_dict()).calc_r0(), axis=1)
         # Tau value
-        df[self.TAU] = self.tau
+        df[self.TAU] = self._tau
         # Step number
-        df[self.STEP_N] = np.random.randint(5, 60, n_trials)
+        df[self.STEP_N] = self._step_n_list
         # Return the setting
         return df
 
@@ -122,7 +125,7 @@ class ModelValidator(Term):
         """
         units = []
         # Instance to save theoretical data
-        example_data = ExampleData(tau=self.tau, start_date="01Jan2020")
+        example_data = ExampleData(tau=self._tau, start_date="01Jan2020")
         # Population values
         population = model.EXAMPLE[self.N.lower()]
         population_data = PopulationData(filename=None)
@@ -130,22 +133,20 @@ class ModelValidator(Term):
         for (i, setting_dict) in enumerate(setting_df.to_dict(orient="records")):
             name = f"{model.NAME}_{i}"
             step_n = setting_dict[self.STEP_N]
-            param_dict = {
-                k: v for (k, v) in setting_dict.items() if k in model.PARAMETERS}
+            param_dict = {k: v for (k, v) in setting_dict.items() if k in model.PARAMETERS}
             # Add theoretical data
-            example_data.add(
-                model, step_n=step_n, country=name, param_dict=param_dict)
+            example_data.add(model, step_n=step_n, country=name, param_dict=param_dict)
             # Population
             population_data.update(population, country=name)
             # Phase unit
-            snl = Scenario(
-                example_data, population_data, country=name, auto_complement=False)
+            snl = Scenario(country=name, auto_complement=False)
+            snl.register(example_data, population_data)
             snl.add()
             unit = snl[self.MAIN].unit("last").del_id().set_id(country=name)
             units.append(unit)
         # Multi-processor for parameter estimation
         processor = MPEstimator(
-            model, jhu_data=example_data, population_data=population_data, tau=self.tau)
+            model, jhu_data=example_data, population_data=population_data, tau=self._tau)
         return processor.add(units)
 
     def _get_result(self, model, setting_df, units_estimated):
@@ -179,15 +180,13 @@ class ModelValidator(Term):
         """
         df = setting_df.copy()
         df["results"] = [unit.to_dict() for unit in units_estimated]
-        df = df.join(
-            df["results"].apply(pd.Series), how="left", rsuffix="_est")
-        df = df.drop(["results", *model.DAY_PARAMETERS], axis=1)
+        df = df.join(df["results"].apply(pd.Series), how="left", rsuffix="_est")
+        df = df.drop(["results", *model.DAY_PARAMETERS], axis=1, errors="ignore")
         cols_to_alternate = [self.RT, *model.PARAMETERS]
         cols_alternated = chain.from_iterable(
             zip(cols_to_alternate, [f"{col}_est" for col in cols_to_alternate]))
         df["ID"] = df[self.ODE].str.cat(df.index.astype("str"), sep="_")
-        columns = [
-            "ID", self.ODE, *cols_alternated, self.STEP_N, *self.EST_COLS]
+        columns = ["ID", self.ODE, *cols_alternated, self.STEP_N, "RMSLE", self.TRIALS, self.RUNTIME]
         return df.loc[:, columns]
 
     def summary(self):
@@ -212,8 +211,7 @@ class ModelValidator(Term):
         """
         df = pd.concat(self._results, ignore_index=True, sort=True)
         pre_cols = ["ID", self.ODE, self.RT, f"{self.RT}_est"]
-        post_cols = [self.STEP_N, *self.EST_COLS]
+        post_cols = [self.STEP_N, "RMSLE", self.TRIALS, self.RUNTIME]
         centers = list(set(df.columns) - set(pre_cols) - set(post_cols))
-        centers_sorted = sorted(
-            centers, key=lambda x: df.columns.tolist().index(x))
+        centers_sorted = sorted(centers, key=lambda x: df.columns.tolist().index(x))
         return df[[*pre_cols, *centers_sorted, *post_cols]]
