@@ -114,7 +114,6 @@ class COVID19DataHub(Term):
     def _download(self):
         """
         Retrieve dataset and citation list from COVID-19 Data Hub.
-        Citation list will be saved to self.
 
         Returns:
             tuple:
@@ -126,19 +125,17 @@ class COVID19DataHub(Term):
             For some countries, province-level data is included.
         """
         warnings.simplefilter("ignore", ResourceWarning)
-        c_res = covid19dh.covid19(
-            country=None, level=1, verbose=False, raw=False)
-        p_res = covid19dh.covid19(
-            country=None, level=2, verbose=False, raw=False)
-        try:
-            c_df, c_cite = c_res
-            p_df, p_cite = p_res
-        except ValueError:
-            # covid19dh <= 1.14
-            c_df, c_cite = c_res.copy(), covid19dh.cite(c_res)
-            p_df, p_cite = p_res.copy(), covid19dh.cite(p_res)
-            citations = list(dict.fromkeys(c_cite + p_cite))
-            return (c_df, p_df, "\n".join(citations))
+        levels = [f"administrative_area_level_{i}" for i in range(1, 4)]
+        # Level 1 (country/region)
+        c_raw, c_cite = covid19dh.covid19(country=None, level=1, verbose=False, raw=True)
+        c_df = c_raw.groupby(levels[0]).ffill().fillna(0)
+        for num in range(3):
+            c_df.loc[:, levels[num]] = c_raw[levels[num]]
+        # Level 2 (province/state)
+        p_raw, p_cite = covid19dh.covid19(country=None, level=2, verbose=False, raw=True)
+        p_df = p_raw.groupby(levels[:2]).ffill().fillna(0)
+        for num in range(3):
+            p_df.loc[:, levels[num]] = p_raw[levels[num]]
         # Citation
         cite = pd.concat([c_cite, p_cite], axis=0, ignore_index=True)
         cite = cite.loc[:, ["title", "year", "url"]]
