@@ -100,7 +100,7 @@ class JHUDataComplementHandler(Term):
                 Index
                     reset index
                 Columns
-                    - Date (pd.TimeStamp): Observation date
+                    - Date (pd.Timestamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Fatal (int): the number of fatal cases
                     - Recovered (int): the number of recovered cases
@@ -113,7 +113,7 @@ class JHUDataComplementHandler(Term):
                     Index
                         reset index
                     Columns
-                        - Date(pd.TimeStamp): Observation date
+                        - Date(pd.Timestamp): Observation date
                         - Confirmed(int): the number of confirmed cases
                         - Infected(int): the number of currently infected cases
                         - Fatal(int): the number of fatal cases
@@ -231,7 +231,7 @@ class JHUDataComplementHandler(Term):
             # Extrapolated value on the date
             series = df.loc[:date, variable]
             series.iloc[-1] = None
-            series.interpolate(method="spline", order=1, inplace=True)
+            series.interpolate(method="linear", inplace=True, limit_direction="both")
             series.fillna(method="ffill", inplace=True)
             # Reduce values to the previous date
             df.loc[:date, variable] = series * raw_last / series.iloc[-1]
