@@ -23,7 +23,7 @@ class MPEstimator(Term):
             Index
                 reset index
             Columns
-                - Date (pd.TimeStamp): Observation date
+                - Date (pd.Timestamp): Observation date
                 - Confirmed (int): the number of confirmed cases
                 - Infected (int): the number of currently infected cases
                 - Fatal (int): the number of fatal cases
